@@ -46,7 +46,7 @@ from sure.six.moves import reduce
 if PY3:
     basestring = str
 
-version = '1.2.2'
+version = '1.2.5'
 
 
 not_here_error = \
@@ -410,6 +410,21 @@ NEGATIVES = [
 ]
 
 
+class IdentityAssertion(object):
+    def __init__(self, assertion_builder):
+        self._ab = assertion_builder
+
+    def __call__(self, other):
+        if self._ab.negative:
+            assert self._ab.obj is not other, "{0} should not be the same object as {1}, but it is".format(self._ab.obj, other)
+            return True
+        assert self._ab.obj is other, "{0} should be the same object as {1}, but it is not".format(self._ab.obj, other)
+        return True
+
+    def __getattr__(self, name):
+        return getattr(self._ab, name)
+
+
 class AssertionBuilder(object):
     def __init__(self, name=None, negative=False, obj=None):
         self._name = name
@@ -452,19 +467,20 @@ class AssertionBuilder(object):
 
     @assertionproperty
     def be(self):
-        return self
+        import os
+        if os.getenv("DEBUG"):
+            import ipdb;ipdb.set_trace()
 
-    @assertionproperty
-    def being(self):
-        return self
 
-    @assertionproperty
-    def not_being(self):
-        return self.should_not
+        return IdentityAssertion(self)
+
+    being = be
 
     @assertionproperty
     def not_be(self):
-        return self.should_not
+        return IdentityAssertion(self.should_not)
+
+    not_being = not_be
 
     @assertionproperty
     def not_have(self):
@@ -524,7 +540,7 @@ class AssertionBuilder(object):
             assert length > 0, (
                 u"expected `{0}` to not be empty".format(representation))
         else:
-            assert length is 0, (
+            assert length == 0, (
                 u"expected `{0}` to be empty but it has {1} items".format(representation, length))
 
         return True
@@ -606,6 +622,7 @@ class AssertionBuilder(object):
 
     eql = equal
     equals = equal
+    equal_to = equal
 
     @assertionmethod
     def an(self, klass):
@@ -859,10 +876,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=False)
             instance = builder(self)
-            callable_args = getattr(self, '_callable_args', None)
+            callable_args = getattr(instance, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(self, '_callable_kw', None)
+            callable_kw = getattr(instance, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
@@ -874,10 +891,10 @@ if is_cpython and allows_new_syntax:
         def method(self):
             builder = AssertionBuilder(name, negative=True)
             instance = builder(self)
-            callable_args = getattr(self, '_callable_args', None)
+            callable_args = getattr(instance, '_callable_args', ())
             if callable_args:
                 instance._callable_args = callable_args
-            callable_kw = getattr(self, '_callable_kw', None)
+            callable_kw = getattr(instance, '_callable_kw', {})
             if callable_kw:
                 instance._callable_kw = callable_kw
             return instance
@@ -903,13 +920,13 @@ if is_cpython and allows_new_syntax:
 old_dir = dir
 
 
-@wraps(builtins.dir)
-def _new_dir(obj=None):
-    if obj is None:
-        frame = inspect.currentframe()
-        return sorted(frame.f_back.f_locals.keys())
-    else:
-        return sorted(set(old_dir(obj)).difference(POSITIVES + NEGATIVES))
+if allows_new_syntax:
+    @wraps(builtins.dir)
+    def _new_dir(obj=None):
+        if obj is None:
+            frame = inspect.currentframe()
+            return sorted(frame.f_back.f_locals.keys())
+        else:
+            return sorted(set(old_dir(obj)).difference(POSITIVES + NEGATIVES))
 
-
-builtins.dir = _new_dir
+    builtins.dir = _new_dir
